import React from 'react';
import { publishDps, View, Text } from '@ray-js/ray';
import { get } from '@ray-js/studio-utils';
import { ActionSheet } from '@tuya-fe/ray-smart-ui/dist/action-sheet';
import { Slider } from '@tuya-fe/ray-smart-ui/dist/slider';
import { useDebounce } from 'ahooks';
// @ts-ignore
import styles from './index.module.less';
export function useDpHandler(_ref) {
  let {
    dpCode,
    dpValue,
    dpSchema,
    Strings
  } = _ref;
  const [enumActions, setEnumActions] = React.useState([]);
  const [showEnum, setShowEnum] = React.useState(false);
  const [showNumber, setShowNumber] = React.useState(false);
  const [currentNumber, setCurrentNumber] = React.useState(0);
  const [ready, setReady] = React.useState(false);
  const currentNumberForSlider = useDebounce(currentNumber, {
    wait: 500
  });
  const handleDp = React.useCallback(() => {
    const {
      mode
    } = dpSchema;

    // if (mode === 'rw' || mode === 'wr') {
    const type = get(dpSchema, 'property.type', '');
    if (type === 'bool') {
      publishDps({
        [dpCode]: !dpValue
      });
    } else if (type === 'enum') {
      const range = get(dpSchema, 'property.range', []);
      const actions = range.map(item => ({
        name: Strings.getDpLang(dpCode, item),
        value: item,
        checked: dpValue === item
      }));
      setEnumActions(actions);
      setShowEnum(true);
    } else if (type === 'value') {
      setCurrentNumber(dpValue);
      setShowNumber(true);
    }
    // }
  }, [dpCode, dpValue, dpSchema, Strings]);
  const handleEnumSelect = React.useCallback(event => {
    const value = get(event, 'detail.value', '');
    const checked = get(event, 'detail.checked', false);
    if (!checked) {
      publishDps({
        [dpCode]: value
      });
      setShowEnum(false);
    }
  }, [dpCode]);
  const handleNumberChange = React.useCallback(value => {
    setCurrentNumber(value);
  }, []);
  const confirmActionSheetNumber = React.useCallback(() => {
    publishDps({
      [dpCode]: currentNumberForSlider
    });
    setShowNumber(false);
  }, [currentNumberForSlider]);
  const onActionSheetReady = React.useCallback(() => setReady(true), []);
  return {
    handleDp,
    renderAction: () => /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(ActionSheet, {
      show: showEnum,
      title: Strings.getDpName(dpCode),
      actions: enumActions,
      cancelText: Strings.getLang('cancel'),
      onSelect: handleEnumSelect,
      onCancel: () => setShowEnum(false),
      onClickOverlay: () => setShowEnum(false)
    }), /*#__PURE__*/React.createElement(ActionSheet, {
      show: showNumber,
      title: Strings.getDpName(dpCode),
      cancelText: Strings.getLang('cancel'),
      confirmText: Strings.getLang('confirm'),
      onClickOverlay: () => {
        setShowNumber(false);
      },
      onCancel: () => {
        setShowNumber(false);
      },
      onConfirm: confirmActionSheetNumber,
      onAfterEnter: onActionSheetReady
    }, /*#__PURE__*/React.createElement(View, {
      className: styles['content-number']
    }, /*#__PURE__*/React.createElement(View, {
      className: styles['demo-header']
    }, /*#__PURE__*/React.createElement(Text, {
      className: styles['demo-text']
    }, `${currentNumber}${get(dpSchema, 'property.unit', '')}`)), /*#__PURE__*/React.createElement(View, {
      className: styles['demo-slider']
    }, ready && /*#__PURE__*/React.createElement(Slider, {
      minTrackRadius: "8px",
      minTrackHeight: "45px",
      maxTrackRadius: "8px",
      maxTrackHeight: "45px",
      max: get(dpSchema, 'property.max', 100),
      min: get(dpSchema, 'property.min', 0),
      value: currentNumberForSlider,
      onChange: handleNumberChange,
      thumbWidth: 15,
      thumbHeight: 50,
      thumbRadius: 2,
      minTrackColor: `var(--app-M1)`,
      thumbStyle: {
        background: '#BBC5D4',
        border: '2px solid #FFFFFF',
        boxShadow: '0px 0px 2px 0px rgba(0, 0, 0, 0.5)'
      }
    })))))
  };
}